[![Build Status](https://travis-ci.com/RustyBower/sopel-cryptocurrency.svg?branch=master)](https://travis-ci.com/RustyBower/sopel-cryptocurrency)
[![Maintainability](https://api.codeclimate.com/v1/badges/3907c6471663c6ee88df/maintainability)](https://codeclimate.com/github/RustyBower/sopel-cryptocurrency/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/3907c6471663c6ee88df/test_coverage)](https://codeclimate.com/github/RustyBower/sopel-cryptocurrency/test_coverage)

# sopel-cryptocurrency
Cryptocurrency Module for Sopel
